.. azure-databricks-sdk-python documentation master file, created by
   sphinx-quickstart on Tue Sep 29 21:14:25 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

azure-databricks-sdk-python documentation!
=======================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   README <README.md>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
